-- | Instrument Invocation
module CsoundExpr.Opcodes.Control.Invocat
    (scoreline_i,
     scoreline)
where



import CsoundExpr.Base.Types
import CsoundExpr.Base.MultiOut
import CsoundExpr.Base.SideEffect
import CsoundExpr.Base.UserDefined



-- | * opcode : scoreline_i
--  
--  
-- * syntax : 
--  
--  >   scoreline_i Sin
--  
--  
-- * description : 
--  
--  scoreline_i will issue score events at i-time. It can handle
-- strings in the same conditions as the standard score. Multi-line
-- strings are accepted, using {{ }} to enclose the string.
--  
--  
-- * url : <http://www.csounds.com/manual/html/scoreline_i.html>
 
scoreline_i :: String -> SignalOut
scoreline_i s0in = outOpcode "scoreline_i" args
  where args = [to s0in]


-- | * opcode : scoreline
--  
--  
-- * syntax : 
--  
--  >   scoreline Sin, ktrig
--  
--  
-- * description : 
--  
--  Scoreline will issue one or more score events, if ktrig is 1
-- every k-period. It can handle strings in the same conditions as
-- the standard score. Multi-line strings are accepted, using {{ }}
-- to enclose the string.
--  
--  
-- * url : <http://www.csounds.com/manual/html/scoreline.html>
 
scoreline :: (K k0) => String -> k0 -> SignalOut
scoreline s0in k1trig = outOpcode "scoreline" args
  where args = [to s0in, to k1trig]